@@ -7,43 +7,60 @@
 #' Run a MCMC sampler on a network model using Stan
 #'
 #' @param model A \code{networkModel}.
-## #' @param dt,grid_size Either the time step size for trajectory calculations
-## #'     (\code{dt}) or the number of points for the calculation
-## #'     (\code{grid_size}) can be provided. If none is provided, then a default
-## #'     grid size of 256 steps is used. Not used for now.
 #' @param iter A positive integer specifying the number of iterations for each
-#'     chain (including warmup). The default is 2000.
+#'   chain (including warmup). The default is 2000.
 #' @param chains A positive integer specifying the number of Markov chains.
-#'     The default is 4.
+#'   The default is 4.
 #' @param method A character string indicating the method to use to solve ODE
-#'     in the Stan model; available methods are "matrix_exp" and "euler". The
-#'     default is "matrix_exp", which uses matrix exponential and is reasonably
-#'     fast for small networks. For large networks, the "euler" method can be
-#'     used. It implements a simple forward Euler method to solve the ODE and
-#'     can be faster than the matrix exponential approach, but extra caution
-#'     must be taken to check for numerical accuracy (e.g. testing different
-#'     \code{dt} time step values, ensuring that the product between \code{dt}
-#'     and the largest transfer rates expected from the priors is always
-#'     very small compared to 1).
+#'   in the Stan model; available methods are "matrix_exp" and "euler". The
+#'   default is "matrix_exp", which uses matrix exponential and is reasonably
+#'   fast for small networks. For large networks, the "euler" method can be
+#'   used. It implements a simple forward Euler method to solve the ODE and can
+#'   be faster than the matrix exponential approach, but extra caution must be
+#'   taken to check for numerical accuracy (e.g. testing different \code{dt}
+#'   time step values, ensuring that the product between \code{dt} and the
+#'   largest transfer rates expected from the priors is always very small
+#'   compared to 1).
 #' @param euler_control An optional list containing extra parameters when using
-#'     \code{method = "euler"}. Allowed list elements are \code{"dt"} and
-#'     \code{"grid_size"}, which are respectively the time step size for
-#'     trajectory calculations (\code{"dt"}) or the number of points for the
-#'     calculation (\code{"grid_size"}). Only one of "dt" or "grid_size" can be
-#'     specified, not both. If none is provided, a default grid size of 256
-#'     steps is used.
+#'   \code{method = "euler"}. Allowed list elements are \code{"dt"} and
+#'   \code{"grid_size"}, which are respectively the time step size for
+#'   trajectory calculations (\code{"dt"}) or the number of points for the
+#'   calculation (\code{"grid_size"}). Only one of "dt" or "grid_size" can be
+#'   specified, not both. If none is provided, a default grid size of 256 steps
+#'   is used.
 #' @param cores Number of cores to use for parallel use. Default is
-#'     \code{NULL}, which means to use the value stored in
-#'     \code{options()[["mc.cores"]]} (or 1 if this value is not set).
+#'   \code{NULL}, which means to use the value stored in
+#'   \code{options()[["mc.cores"]]} (or 1 if this value is not set).
 #' @param stanfit If TRUE, returns a `stanfit` object instead of the more
-#'     classical `mcmc.list` object.
+#'   classical `mcmc.list` object. Note that when an `mcmc.list` object is
+#'   returned, the original `stanfit` object is still accessible as an
+#'   attribute of that object (see Examples).
 #' @param ... Arguments passed to `rstan::sampling` (e.g. iter, chains).
 #'
 #' @return An object of class `stanfit` returned by `rstan::sampling` if
-#'     \code{stanfit = TRUE}, otherwise the result of converting this
-#'     \code{stanfit} object with \code{stanfit_to_named_mcmclist} (i.e. an
-#'     object of class \code{networkModelStanfit} and {mcmc.list}).
+#'   \code{stanfit = TRUE}, otherwise the result of converting this
+#'   \code{stanfit} object with \code{stanfit_to_named_mcmclist} (i.e. an
+#'   object of class \code{networkModelStanfit} and {mcmc.list}, which still
+#'   carries the original `stanfit` object stored as an attribute).
 #'
+#' @examples
+#' aquarium_mod
+#' \dontrun{
+#'   # The 'aquarium_run' object is shipped with the package, so you don't
+#'   # actually need to run the line below to obtain it
+#'   aquarium_run <- run_mcmc(aquarium_mod)
+#' 
+#'   plot(aquarium_run)
+#'   summary(aquarium_run)
+#'
+#'   # The original stanfit object returned by Stan
+#'   sfit <- attr(aquarium_run, "stanfit")
+#'   sfit
+#'
+#'   # The stanfit object can be used for diagnostics, LOO cross-validation, etc.
+#'   rstan::loo(sfit)
+#' }
+#' 
 #' @export
 
 ### ** Code
@@ -80,7 +97,8 @@ run_mcmc <- function(model, iter = 2000, chains = 4, method = "matrix_exp",
 #' 
 #' @param stanfit A stanfit object returned by \code{rstan::sampling}.
 #' 
-#' @return An \code{mcmc.list} object.
+#' @return An \code{mcmc.list} object. It also has the original stanfit object
+#'   stored as an attribute \code{"stanfit"}.
 #'
 #' @export
 
@@ -90,8 +108,8 @@ stanfit_to_named_mcmclist <- function(stanfit) {
     # Get mcpars
     start <- fit@sim[["warmup"]] + 1
     end <- fit@sim[["iter"]]
-    thin <- 1
-    n_kept <- end - start + 1
+    thin <- fit@sim[["thin"]]
+    n_kept <- fit@sim[["n_save"]] - fit@sim[["warmup2"]]
     mcpars <- c(start, end, thin)
     # Prepare the mcmc.list object
     out <- rstan::As.mcmc.list(fit)
@@ -123,5 +141,6 @@ stanfit_to_named_mcmclist <- function(stanfit) {
     }
     # Return the mcmc.list object
     outClass <- c("networkModelStanfit", class(out))
+    attr(out, "stanfit") <- stanfit
     return(structure(out, class = outClass))
 }
